/*****************************************************************************/
/*!
\file      hardware.c
\brief     port initialisation 
                         

\implementation
  project       Multimedia Gateway
  version       0.00
  copyright     Matthias Koelling 
  
  generated     Matthias Koelling 07.06.2008
  review
  released

  compiler      AVR GCC
  target        ATmega128-16AU
\endimplementation

\history  
  Rev     Date         Author      Commentary
  0.00    07.06.2008   Koelling    generated
\endhistory  
*/
/*****************************************************************************/

/* -- Configuration Parameters --------------------------------------------- */

#define IO_C

/* -- Includes ------------------------------------------------------------- */

#include <avr/io.h>
#include <avr/sfr_defs.h>
#include <stdlib.h>
#include <avr/interrupt.h>
#include <avr/pgmspace.h>
#include <util/delay.h>
#include "main.h"
#include "com.h"
#include "hardware.h"

/* -- Makros --------------------------------------------------------------- */

/* -- Defines -------------------------------------------------------------- */ 

/* -- Types ---------------------------------------------------------------- */

/* -- Module Global Variables ---------------------------------------------- */

/* -- Extern Global Variables ---------------------------------------------- */

/* -- Makros --------------------------------------------------------------- */

/* -- Implementation Functions --------------------------------------------- */

//-----------------------------------------------------------------------------
/*!
   \brief     Init_IO_fv

    port initialisation

   \author     Koelling
   \date       07.06.2008

   \param[in]  void
   \param[out] none
   \return     void
*/
//-----------------------------------------------------------------------------

void Init_IO_fv(void)
{
	uint8_t i;
   uint8_t signal_type_u8;
	uint8_t bit_mask_u8;
   uint8_t *DDR_Reg_pu8; 	
   uint8_t *PORT_Reg_pu8;	
   
   for(i = 0;i < (sizeof(Dio_Inputs_cat) / sizeof(Digital_Signals_t));i++)
	{
      signal_type_u8 = pgm_read_byte(&Dio_Inputs_cat[i].SignalType_u8);
		bit_mask_u8 = pgm_read_byte(&Dio_Inputs_cat[i].BitMask_u8);
      DDR_Reg_pu8 = (uint8_t*)pgm_read_word(&Dio_Inputs_cat[i].DDR_Reg_pu8);
      PORT_Reg_pu8 = (uint8_t*)pgm_read_word(&Dio_Inputs_cat[i].PORT_Reg_pu8);
      
      if(signal_type_u8 == OUT) // only outputs to configure
		{
			*DDR_Reg_pu8 |= 1 << bit_mask_u8;
		}
      else
      {
         if(signal_type_u8 == PULL_UP)
         {
      	   *PORT_Reg_pu8 |= 1 << bit_mask_u8;
		   }
      }
	}
   LED_POWER = ON;	
}
