/*****************************************************************************/
/*!
\file      hardware.h
\brief     header for hardware.c

\implementation
  project       Multimedia Gateway
  version       0.00
  copyright     Matthias Klling 
  
  generated     Matthias Koelling 05.06.2008
  review
  released

  compiler      AVR GCC
  target        ATmega1280-16AU
\endimplementation

\history  
  Rev     Date         Author      Commentary
  0.01    27.04.2008   Koelling    adaptaption for gateway4
  0.00    05.06.2008   Koelling    generated
\endhistory  
*/
/*****************************************************************************/

#ifndef __HARDWARE_h
#define __HARDWARE_h

/* -- Includes ------------------------------------------------------------- */

/* -- Configuration Parameters --------------------------------------------- */

/* -- Makros --------------------------------------------------------------- */

#define SBIT(port,pin) ((*(volatile bits*)&port).b##pin)

#define FTDI_OUT(Data_u8) {DDRA = 0xFF;\
                           PORTA = Data_u8;}

#define FTDI_IN(Data_u8)  {DDRA = 0;\
                           Data_u8 = PINA;}

#define VOICE_IN(Data_u8) {DDRK = 0;\
                           Data_u8 = PINK;}

/* -- Defines -------------------------------------------------------------- */ 

#define IN       0
#define OUT      1
#define PULL_UP  2

/* ------------------------------------------------------------------------- */ 
// PORT A
/* ------------------------------------------------------------------------- */ 

// used as FTDI data port

/* ------------------------------------------------------------------------- */ 
// PORT B
/* ------------------------------------------------------------------------- */ 

#define CSN              SBIT(PORTB,0)
#define SCK              SBIT(PORTB,1)
#define MOSI             SBIT(PORTB,2)
#define MISO             SBIT(PINB,3)
#define E_INT_MP3        SBIT(PORTB,4)
#define _PB5             SBIT(PIN,5)    // unused
#define _PB6             SBIT(PIN,6)    // unused
#define COMMAND_GATEWAY  SBIT(PORTB,7)

/* ------------------------------------------------------------------------- */ 
// PORT C
/* ------------------------------------------------------------------------- */ 

#define MUTE             SBIT(PINC,0)
#define BAR              SBIT(PORTC,1)
#define CO               SBIT(PINC,2)
#define _PC3             SBIT(PINC,3)   // unused
#define RXF              SBIT(PINC,4)
#define TXE              SBIT(PINC,5)
#define WR               SBIT(PORTC,6)
#define RD               SBIT(PORTC,7)

/* ------------------------------------------------------------------------- */ 
// PORT D
/* ------------------------------------------------------------------------- */ 

//#define SCL            SBIT(PORTD,0)    // I2C
//#define SDA            SBIT(PORTD,1)    // I2C
//#define RXD1           SBIT(PIND,2)     // UART1
//#define TXD1           SBIT(PORTD,3)    // UART1
#define COMMAND_RADIO    SBIT(PIND,4)
#define _PD5             SBIT(PIND,5)     // unused
#define SEL_I2C          SBIT(PORTD,6)     
#define KL58             SBIT(PIND,7)

/* ------------------------------------------------------------------------- */ 
// PORT E
/* ------------------------------------------------------------------------- */ 

//#define RXD0           SBIT(PINE,0)     // UART0
//#define TXD0           SBIT(PORTC,1)    // UART0
#define _PE2             SBIT(PINE,2)     // unused
#define _PE3             SBIT(PINE,3)     // unused
#define _PE4             SBIT(PINE,4)     // unused
#define DATA_CDC         SBIT(PINE,5)
#define CLK_CDC          SBIT(PINE,6)
#define IR               SBIT(PINE,7)

/* ------------------------------------------------------------------------- */ 
// PORT F
/* ------------------------------------------------------------------------- */ 

#define _PF0             SBIT(PINF,0)      // unused
#define _PF1             SBIT(PINF,1)      // unused
#define _PF2             SBIT(PINF,2)      // unused
#define _PF3             SBIT(PINF,3)      // unused
#define LED_AUX          SBIT(PORTF,4)
#define LED_CDC          SBIT(PORTF,5)
#define LED_MP3          SBIT(PORTF,6)
#define LED_POWER        SBIT(PORTF,7)

/* ------------------------------------------------------------------------- */ 
// PORT G
/* ------------------------------------------------------------------------- */ 

#define _PG0             SBIT(PING,0)      // unused
#define _PG1             SBIT(PING,1)      // unused
#define _PG2             SBIT(PING,2)      // unused
#define _PG3             SBIT(PING,3)      // unused
#define _PG4             SBIT(PING,4)      // unused
#define _PG5             SBIT(PING,5)      // unused

/* ------------------------------------------------------------------------- */ 
// PORT H
/* ------------------------------------------------------------------------- */ 

#define _PH0             SBIT(PINH,0)      // unused
#define DATA_GATEWAY     SBIT(PORTH,1)
#define CLK_GATEWAY      SBIT(PORTH,2)
#define MUX_A            SBIT(PORTH,3)
#define MUX_B            SBIT(PORTH,4)
#define MUX_C            SBIT(PORTH,5)
#define ENABLE_MP3       SBIT(PORTH,6)
#define ENABLE_CDC       SBIT(PORTH,7)

/* ------------------------------------------------------------------------- */ 
// PORT J
/* ------------------------------------------------------------------------- */ 

#define _PJ0             SBIT(PINJ,0)      // unused
#define KOMBIDATA        SBIT(PORTJ,1)
#define KOMBICLOCK       SBIT(PORTJ,2)
#define _PJ3             SBIT(PINJ,3)      // unused
#define _PJ4             SBIT(PINJ,4)      // unused
#define KOMBIENABLE      SBIT(PORTJ,5)
#define RADIOENABLE      SBIT(PINJ,6)
#define _PJ7             SBIT(PINJ,7)      // unused
  
/* ------------------------------------------------------------------------- */ 
// PORT K
/* ------------------------------------------------------------------------- */ 

// used as Voice direct data port

/* ------------------------------------------------------------------------- */ 
// PORT L
/* ------------------------------------------------------------------------- */ 

#define RADIODATA        SBIT(PINL,0)
#define RADIOCLOCK       SBIT(PINL,1)
#define _PL2             SBIT(PINL,2)      // unused
#define RADIO_12V        SBIT(PINL,3)
#define ERROR_KLINE      SBIT(PINL,4)
#define CS_KLINE         SBIT(PORTL,5)
#define _PL6             SBIT(PINL,6)      // unused
#define RESET            SBIT(PINL,7)      // ???


/* -- Types ---------------------------------------------------------------- */

typedef struct {
  uint8_t b0:1;
  uint8_t b1:1;
  uint8_t b2:1;
  uint8_t b3:1;
  uint8_t b4:1;
  uint8_t b5:1;
  uint8_t b6:1;
  uint8_t b7:1;
}bits;

typedef struct                              
{
   uint8_t *DDR_Reg_pu8;          // data direction register            
   uint8_t *PORT_Reg_pu8;         // port register for pull up init            
   uint8_t BitMask_u8;            // Which bit does the signal use
   uint8_t SignalType_u8;         // Input or Output
}Digital_Signals_t;                        

/* -- Extern Global Variables ---------------------------------------------- */

#ifdef IO_C

   const Digital_Signals_t Dio_Inputs_cat[] PROGMEM = 
   {
      // PORT A
      // used as FTDI data port
      // PORT B
      { &DDRB, &PORTB, 0, OUT     },      // CSN               
      { &DDRB, &PORTB, 1, OUT     },      // CLOCK            
      { &DDRB, &PORTB, 2, OUT     },      // MOSI             
      { &DDRB, &PORTB, 3, IN      },      // MISO
      { &DDRB, &PORTB, 4, OUT     },      // E_INT_MP3              
      { &DDRB, &PORTB, 5, IN      },      // _PB5 unused             
      { &DDRB, &PORTB, 6, IN      },      // _PB6 unused            
      { &DDRB, &PORTB, 7, OUT     },      // COMMAND_GATEWAY  
      // PORT C
      { &DDRC, &PORTC, 0, IN      },      // MUTE              
      { &DDRC, &PORTC, 1, OUT     },      // BAR              
      { &DDRC, &PORTC, 2, IN      },      // CO                
      { &DDRC, &PORTC, 3, IN      },      // _PC3 unused              
      { &DDRC, &PORTC, 4, IN      },      // RXF               
      { &DDRC, &PORTC, 5, IN      },      // TXE               
      { &DDRC, &PORTC, 6, OUT     },      // WR               
      { &DDRC, &PORTC, 7, OUT     },      // RD               
      // PORT D
      // { &DDRD, &PORTD, 0, IN    },     // SCL               // I2C
      // { &DDRD, &PORTD, 1, OUT   },     // SDA               // I2C
      // { &DDRD, &PORTD, 2, IN    },     // RXD1              // UART1
      // { &DDRD, &PORTD, 3, OUT   },     // TXD1              // UART1
      { &DDRD, &PORTD, 4, PULL_UP },      // COMMAND_RADIO     
      { &DDRD, &PORTD, 5, IN      },      // _PD5 unused      
      { &DDRD, &PORTD, 6, OUT     },      // SEL_I2C     
      { &DDRD, &PORTD, 7, IN      },      // KL58              
      // PORT E
      // { &DDRE, &PORTE, 0, IN   },      // RXD0              // UART0
      // { &DDRE, &PORTE, 1, IN   },      // TXD0              // UART0
      { &DDRE, &PORTE, 2, IN      },      // _PE2 unused          
      { &DDRE, &PORTE, 3, IN      },      // _PE3 unused         
      { &DDRE, &PORTE, 4, IN      },      // _PE4 unused        
      { &DDRE, &PORTE, 5, PULL_UP },      // DATA_CDC       
      { &DDRE, &PORTE, 6, PULL_UP },      // CLK_CDC           
      { &DDRE, &PORTE, 7, IN      },      // IR                
      // PORT F
      { &DDRF, &PORTF, 0, IN      },      // _PF0 unused          
      { &DDRF, &PORTF, 1, IN      },      // _PF1 unused          
      { &DDRF, &PORTF, 2, IN      },      // _PF2 unused          
      { &DDRF, &PORTF, 3, IN      },      // _PF3 unused          
      { &DDRF, &PORTF, 4, OUT     },      // LED_AUX      
      { &DDRF, &PORTF, 5, OUT     },      // LED_CDC      
      { &DDRF, &PORTF, 6, OUT     },      // LED_MP3      
      { &DDRF, &PORTF, 7, OUT     },      // LED_POWER      
      // PORT G
      { &DDRG, &PORTG, 0, IN      },      // _PG0 unused          
      { &DDRG, &PORTG, 1, IN      },      // _PG1 unused          
      { &DDRG, &PORTG, 2, IN      },      // _PG2 unused          
      { &DDRG, &PORTG, 3, IN      },      // _PG3 unused          
      { &DDRG, &PORTG, 4, IN      },      // _PG4 unused          
      { &DDRG, &PORTG, 5, IN      },      // _PG5 unused          
      // PORT H
      { &DDRH, &PORTH, 0, IN      },      // _PH0 unused          
      { &DDRH, &PORTH, 1, OUT     },      // DATA_GATEWAY          
      { &DDRH, &PORTH, 2, OUT     },      // CLK_GATEWAY          
      { &DDRH, &PORTH, 3, OUT     },      // MUX_A          
      { &DDRH, &PORTH, 4, OUT     },      // MUX_B  
      { &DDRH, &PORTH, 5, OUT     },      // MUX_C  
      { &DDRH, &PORTH, 6, OUT     },      // ENABLE_MP3    
      { &DDRH, &PORTH, 7, OUT     },      // ENABLE_CDC      
      // PORT J
      { &DDRJ, &PORTJ, 0, IN      },      // _PJ0 unused          
      { &DDRJ, &PORTJ, 1, OUT     },      // KOMBIDATA          
      { &DDRJ, &PORTJ, 2, OUT     },      // KOMBICLOCK          
      { &DDRJ, &PORTJ, 3, IN      },      // _PJ3 unused          
      { &DDRJ, &PORTJ, 4, IN      },      // _PJ4 unused  
      { &DDRJ, &PORTJ, 5, OUT     },      // KOMBIENABLE  
      { &DDRJ, &PORTJ, 6, IN      },      // RADIOENABLE    
      { &DDRJ, &PORTJ, 7, IN      },      // _PJ7 unused      
      // PORT K
      // used as Voice direct data port
      { &DDRK, &PORTK, 0, IN      },      // Voice direct data0          
      { &DDRK, &PORTK, 1, IN      },      // Voice direct data1          
      { &DDRK, &PORTK, 2, IN      },      // Voice direct data2          
      { &DDRK, &PORTK, 3, IN      },      // Voice direct data3          
      { &DDRK, &PORTK, 4, IN      },      // Voice direct data4          
      { &DDRK, &PORTK, 5, IN      },      // Voice direct data5          
      { &DDRK, &PORTK, 6, IN      },      // Voice direct data6          
      { &DDRK, &PORTK, 7, IN      },      // Voice direct data7          
      // PORT L
      { &DDRL, &PORTL, 0, IN      },      // RADIODATA          
      { &DDRL, &PORTL, 1, IN      },      // RADIOCLOCK          
      { &DDRL, &PORTL, 2, IN      },      // _PL2 unused          
      { &DDRL, &PORTL, 3, IN      },      // RADIO_12V          
      { &DDRL, &PORTL, 4, IN      },      // ERROR_KLINE  
      { &DDRL, &PORTL, 5, OUT     },      // CS_KLINE  
      { &DDRL, &PORTL, 6, IN      },      // _PL6 unused    
      { &DDRL, &PORTL, 7, IN      },      // RESET      
   }; 
#endif

/* -- Global Function Prototypes ------------------------------------------- */

extern void Init_IO_fv(void);

#endif // __HARDWARE_h 

// eof //
