#define STV_DATA        PB2
#define STV_DATA_DDR  DDB2
#define STV_CLK         PB1
#define STV_CLK_DDR  DDB1
#define STV_CSN      PB0
#define STV_CSN_DDR  DDB0
#define STV_MUTE      PA3
#define STV_MUTE_DDR  DDA3

#define BLACK       0
#define BLUE        1
#define GREEN       2
#define CYAN        3
#define RED        4
#define MAGENTA 5
#define YELLOW      6
#define WHITE       7


#define DATA (1 << 12)
// definition for character format and attributes
#define BK(x) (((uint16_t)x & 0x01) << 7)          // blink attribute
#define RGB(x) (((uint16_t)x & 0x07) << 8)         // color attribute
#define BE(x) (((uint16_t)x & 0x01) << 11)          // background enable/disable

// definition for row attributes
#define VPOS_OFFSET(x) (((uint16_t)x & 0x3F) << 0) // VPOS_OFFSET
#define FBE(x) (((uint16_t)x & 0x01) << 6)         // character border enable/disable
#define RE(x) (((uint16_t)x & 0x01) << 7)          // row enable/disable
#define HPOS_OFFSET(x) (((uint16_t)x & 0x0F) << 8) // HPOS_OFFSET

// definition for zoom register
#define HZT(x) (((uint16_t)x & 0x03) << 0)    // horizontal zoom top line
#define VZT(x) (((uint16_t)x & 0x03) << 2)    // vertical zoom top line
#define HZM(x) (((uint16_t)x & 0x03) << 4)    // horizontal zoom middle lines
#define VZM(x) (((uint16_t)x & 0x03) << 6)    // vertical zoom middle lines
#define HZB(x) (((uint16_t)x & 0x03) << 8)    // horizontal zoom bottom line
#define VZB(x) (((uint16_t)x & 0x03) << 10)   // vertical zoom bottom line

// definition for color register
#define BCC(x) (((uint16_t)x & 0x07) << 0)    // character background color
#define FBC(x) (((uint16_t)x & 0x03) << 6)    // character border color
#define SBC(x) (((uint16_t)x & 0x07) << 9)    // screen background color

// definition for control register
#define C0 (1 << 0)     // C0 = 0: mixed mode
                        // C0 = 1: full page mode
#define C1 (1 << 1)     // C1 = 0: the character background is controlled by BE (see character word description)
                        // C1 = 1: all displayed character backgrounds are disabled
#define C2 (1 << 2)     // C2 = 0: display off
                        // C2 = 1: display on
#define C3 (1 << 3)     // C3 = 0: the characters are colored according to the character attribute 
                        //         and the color register values (i.e. CBACKG and CBORD)
                        // C3 = 1: the character foreground, border and background colors are all
                        //         set to the characterattribute value (see paragraph 1.2). 
                        //         This option is mainly intended for full page mode, CVBS or Y/C output
#define C4 (1 << 4)     // C4 = 0: 1.0 second blinking period
                        // C4 = 1: 0.5 second blinking period

#define C5 (1 << 5)     // C[6:5] = 00: blinking off
                        //          01: 0.75 blinking duty cycle
#define C6 (1 << 6)     //          10: 0.5 blinking duty cycle
                        //          11: 0.25 blinking duty cycle
#define C7 (1 << 7)     // C7 = 0: an external input composite sync is taken from the CSYNC pin
                        // C7 = 1: the sync is extracted by the STV5730.The currently active sync 
                        //         is output on the CSYNC pin
#define C8 (1 << 8)     // C8 = 0: the standard is NTSC, 60Hz
                        // C8 = 1: the standard is PAL or SECAM with M6 = 0, 50Hz
#define C9 (1 << 9)     // C9 = 0: character color encoding is disabled
                        // C9 = 1: character color encoding is enabled
#define C10 (1 << 10)   // C10 = 0: the luminance levels are generated internally
                        // C10 = 1: the luminance levels are provided by the LESCREEN and LECHAR
                        //          input pins.
#define C11 (1 << 11)   // C11 = 0: Video Full Page Mode. A stable full page mode text is displayed 
                        //          while the screen background is the unlocked video input signal.
                        // C11 = 1: Normal full page mode is active.

// definition for position register
#define HPOS (0x3f << 0)   // HORIZONTAL POSITION Any value from 6 to 63
#define VPOS (0x3f << 6)   // VERTICAL POSITION Any value from 1 to 63

// definition for mode register

#define M0 (1 << 0)     // M0 = 0: the BAR pin is disabled
                        // M0 = 1: the BAR pin has an action on the line PLL
#define M1 (1 << 1)     // M1 = 0: the missing sync pulses are not detected
                        // M1 = 1: the missing sync pulses are detected
#define M2 (1 << 2)     // M2 = 0: the MUTE pin is forced to 0
                        // M2 = 1: the MUTE pin delivers the internal MUTE signal
#define M3 (1 << 3)     // M3 = 0: the MUTE time constant is 8 lines
                        // M3 = 1: the MUTE time constant is 32 lines
#define M4 (1 << 4)     // M4 = 0: the sync is not re-inserted
                        // M4 = 1: the sync is re-inserted for improved text stability
#define M5 (1 << 5)     // M5 = 0: the gain of pins VIDEO OUT1 & VIDEO OUT2 is 0dB.
                        // M5 = 1: the gain of pins VIDEO OUT1 & VIDEO OUT2 is 6dB.
#define M6 (1 << 6)     // M6 = 0: the color encoder is enabled (PAL or NTSC)
                        // M6 = 1: the color encoder is disabled (B&W or SECAM)
#define M7 (1 << 7)     // M7 = 0: the VIDEO OUT2 pin outputs the VIDEO IN signal
                        // M7 = 1: the VIDEO OUT2 pin outputs the composite sync
#define M8 (1 << 8)     // M8 = 0: the VIDEO OUT2 pin is in high impedance state
                        // M8 = 1: the VIDEO OUT2 pin is in low impedance state
#define M9 (1 << 9)     // M9    : This Mode bit has to be kept at a low level.
#define M10 (1 << 10)   // M10 = 0: No delay compensation
                        // M10 = 1: It enables the delay compensation of the internal sync extractor.
#define M11 (1 << 11)   // M11 = 0: The mute signal output is synchronized on vertical sync in order 
                        //          to limit its transitions.
                        // M11 = 1: The mute signal is not synchronized on vertical sync thus 
                        //          accelerating the VIDEO IN presence detection (useful in full page mode).

// definitions for write pointer
#define DEPL(x) (((uint16_t)x & 0x0F) << 0)   // see data sheet
#define STRU(x) (((uint16_t)x & 0x03) << 7)   //
#define BUF(x) (((uint16_t)x & 0x03) << 11)    //

#define WRITE_POINTER(buf,stru,depl) (BUF(buf) | STRU(stru) | DEPL(depl))

extern void OSD(void);
extern void Init_OSD(void);
extern void OSD_Test_Screen_fv(void);
extern void putc_stv5730(uint8_t x_pos_u8, uint8_t y_pos_u8, uint16_t char_u16);
extern void Clear_Row_STV5730_fv(uint8_t row_u8);
extern void Redraw_Row_STV5730_fv(uint8_t row_u8, uint8_t vscroll_offset_u8); 
extern void Redraw_Page_STV5730_fv(uint8_t vscroll_offset_u8);
extern void Clear_Page_STV5730_fv(void);
extern void Set_Display_Config_fv(uint8_t x_offset_u8,uint8_t y_offset_u8, uint8_t colums_u8, uint8_t rows_u8);
extern void Switch_Display_fv(uint8_t on_off_u8);
extern void setDisplayedLine(uint8_t line, uint8_t Displayed);
