/*****************************************************************************/
/*!
\file      sw_trimer.c
\brief     this module is used to handle flexible timing events                                                                                                                     
                         

\implementation
  project       Multimedia Gateway
  version       0.00
  copyright     Matthias Koelling 
  
  generated     Matthias Koelling 03.03.2008
  review
  released

  compiler      AVR GCC
  target        ATmega128-16AU
\endimplementation

\history  
  Rev     Date         Author      Commentary
  0.00    21.06.2008   Koelling    generated
\endhistory  
*/
/*****************************************************************************/

/* -- Includes ------------------------------------------------------------- */

#include <avr/io.h>
#include <stdlib.h>
#include <string.h>
#include <avr/interrupt.h>
#include <avr/pgmspace.h>
#include "main.h"
#include "device.h"
#include "display.h"
#include "sw_timer.h"

/* -- Configuration Parameters --------------------------------------------- */

/* -- Makros --------------------------------------------------------------- */

/* -- Defines -------------------------------------------------------------- */ 

#define NUM_SW_TIMER     5  // number of maximum active sw timer requests

/* -- Types ---------------------------------------------------------------- */

typedef struct
{
   void(*CallBack_pfv)(void); // function pointer to call back function
   uint8_t sw_timer_u8;
}SW_TIMER_T;

/* -- Modul Global Function Prototypes ------------------------------------- */

/* -- Module Global Variables ---------------------------------------------- */

static SW_TIMER_T sw_timer_mat[NUM_SW_TIMER];

/* -- Extern Global Variables ---------------------------------------------- */

/* -- Implementation Functions --------------------------------------------- */

//-----------------------------------------------------------------------------
/*!
   \brief     void Init_SW_Timer_fv(void)

    initialization of IR decoder and event handler

   \author     Koelling
   \date       21.06.2008

   \param[in]  void
   \param[out] none
   \return     void
*/
//-----------------------------------------------------------------------------

void Init_SW_Timer_fv(void)
{
   uint8_t i;

   for(i = 0;i < NUM_SW_TIMER;i++)
   {
      sw_timer_mat[i].CallBack_pfv = NULL;
      sw_timer_mat[i].sw_timer_u8 = 0;
   }
}

//-----------------------------------------------------------------------------
/*!
   \brief     void Set_SW_Timer_fv(sw_timer_e timer_num_e, uint8_t time_u8)

    initialization of IR decoder and event handler

   \author     Koelling
   \date       21.06.2008

   \param[in]  void
   \param[out] none
   \return     void
*/
//-----------------------------------------------------------------------------

void Set_SW_Timer_fv(uint8_t time_u8, void(*call_back_pfv)(void))
{
   uint8_t i;

   for(i = 0;i < NUM_SW_TIMER;i++)
   { 
      if(sw_timer_mat[i].CallBack_pfv == NULL) // look for free slot
      {
         sw_timer_mat[i].CallBack_pfv = call_back_pfv;
         sw_timer_mat[i].sw_timer_u8 = time_u8;
      }
   }
}


//-----------------------------------------------------------------------------
/*!
   \brief     void SW_Timer_10ms_fv(void)

    initialization of IR decoder and event handler

   \author     Koelling
   \date       21.06.2008

   \param[in]  void
   \param[out] none
   \return     void
*/
//-----------------------------------------------------------------------------

void SW_Timer_50ms_fv(void)
{
   uint8_t i;

   for(i = 0;i < NUM_SW_TIMER;i++)
   {
      if(sw_timer_mat[i].sw_timer_u8 > 0)
      {
         sw_timer_mat[i].sw_timer_u8--;
         if(sw_timer_mat[i].sw_timer_u8 == 0)
         {
            if(sw_timer_mat[i].CallBack_pfv != NULL) // look for null pointer
            { 
               sw_timer_mat[i].CallBack_pfv();
            }
         }      
      }
   }
}

// eof //
