/*****************************************************************************/
/*!
\file      task.c
\brief     task funktions for mini non preemptive operating system              

\implementation
  project       Multimedia Gateway
  version       0.00
  copyright     2008 Matthias Koelling 
  
  generated     Matthias Koelling 12.02.2008
  review
  released

  compiler      AVR GCC
  target        ATmega128-16AU
\endimplementation

\history  
  Rev     Date         Author      Commentary
  0.00    12.02.2007   Koelling    generated
\endhistory  
*/
/*****************************************************************************/

/* -- Includes ------------------------------------------------------------- */

#include <avr/io.h>
#include <avr/sfr_defs.h>
#include <avr/pgmspace.h>
#include <stdlib.h>
#include "main.h"
#include "vwcdc.h"
#include "device.h"
#include "display.h"
#include "ir.h"
#include "com.h"
#include "hardware.h"
#include "sw_timer.h"
#include "task.h"

//-----------------------------------------------------------------------------
/*!
   \brief     void Task_10ms_fv(void)

    10ms Task

   \author     Matthias Koelling
   \date       12.02.2008

   \param[in]  none
   \param[out] none
   \return     void
*/
//-----------------------------------------------------------------------------

void Task_10ms_fv(void)
{
   CDC_Protocol_10ms_fv();
   #ifndef TEST_SCREEN
      Display_fv();
   #endif
}


//-----------------------------------------------------------------------------
/*!
   \brief     void Task1_50ms_fv(void)

    50ms Task1 correlated to 10ms Task

   \author     Matthias Koelling
   \date       12.02.2008

   \param[in]  none
   \param[out] none
   \return     void
*/
//-----------------------------------------------------------------------------

void Task1_50ms_fv(void)
{
   //LED_POWER = ~MUTE;
   CDC_Protocol_50ms_fv();
   IR_Command_50ms_fv();
   SW_Timer_50ms_fv();
   //   LED_POWER ^= 1;
}


//-----------------------------------------------------------------------------
/*!
   \brief     void Task2_50ms_fv(void)

    50ms Task2 with 20ms offset to 50ms Task1

   \author     Matthias Koelling
   \date       12.02.2008

   \param[in]  none
   \param[out] none
   \return     void
*/
//-----------------------------------------------------------------------------

void Task2_50ms_fv(void)
{
}


//-----------------------------------------------------------------------------
/*!
   \brief     void Task_500ms_fv(void)

    500ms Task correlated to 50ms Task2

   \author     Matthias Koelling
   \date       12.02.2008

   \param[in]  none
   \param[out] none
   \return     void
*/
//-----------------------------------------------------------------------------

void Task_500ms_fv(void)
{
   static uint8_t task_counter_hu8 = 0;
   
   if(task_counter_hu8 == 4)
   {
      Init_OSD();
      Init_Display_fv();
      Display_Active_Device_fv(Get_Last_Device_fe());
      Redraw_Page_fv();
   }
   if(task_counter_hu8 < 5) task_counter_hu8++;
   
   //if(MUTE) LED_AUX = 0;
   //else LED_AUX = 1;
   //Send_Gateway_Command_fv(M_ENABLE);
}
