/*****************************************************************************/
/*!
\file      tda7439.c
\brief     driver and handling functions for TWI (I2C)              

\implementation
  project       Multimedia Gateway
  version       0.00
  copyright     
  
  generated     Matthias Koelling 26.04.2009
  review
  released

  compiler      AVR GCC
  target        ATmega1280-16AU
\endimplementation

\history  
  Rev     Date         Author      Commentary
  0.00    26.04.2009   Koelling    generated
\endhistory  
*/
/*****************************************************************************/

/* -- Includes ------------------------------------------------------------- */

#include <avr/io.h>
#include <util/delay.h>
#include "hardware.h"
#include "main.h"
#include "twi.h"
#include "printf.h"
#include "tda7439.h"

/* -- Configuration Parameters --------------------------------------------- */

/* -- Makros --------------------------------------------------------------- */

/* -- Defines -------------------------------------------------------------- */ 

/* -- Types ---------------------------------------------------------------- */

/* -- Modul Global Function Prototypes ------------------------------------- */

/* -- Module Global Variables ---------------------------------------------- */

/* -- Extern Global Variables ---------------------------------------------- */

/* -- Implementation Functions --------------------------------------------- */

//-----------------------------------------------------------------------------
/*!
   \brief     Init_TDA7439

    initialise TDA7439 with default values

   \author     Koelling
   \date       26.04.2009

   \param[in]  void
   \param[out] none
   \return     void
*/
//-----------------------------------------------------------------------------

void Init_TDA7439(void)
{
   SEL_I2C = TRUE;
   TDA7439_send_byte(SPK_ATTN_L,0x00);  // set volume to 0dB for left channel
   TDA7439_send_byte(SPK_ATTN_R,0x00);  // set volume to 0dB for right channel
   TDA7439_send_byte(MIDDLE,0x0F);      // set middle to 0dB
   TDA7439_send_byte(TREBLE,0x0F);      // set treble to 0dB
   TDA7439_send_byte(VOLUME,VOL_MUTE);  // mute outputs
   SEL_I2C = FALSE;
}


//-----------------------------------------------------------------------------
/*!
   \brief     Sel_Audio_MP3_fv

    this function controls the TDA7439 to switch to MP3 

   \author     Matthias Koelling
   \date       26.04.2009

   \param[in]  void
   \param[out] none
   \return     none
*/
//-----------------------------------------------------------------------------

void Sel_Audio_MP3_fv(void)
{
   SEL_I2C = TRUE;
   TDA7439_send_byte(VOLUME,VOL_MUTE); // mute outputs
   TDA7439_send_byte(IN_SELECT,IN3);   // select input1 -> MP3
   TDA7439_send_byte(IN_GAIN,8);       // set gain to 8dB
   TDA7439_send_byte(VOLUME,MAIN_VOL);        // set volume to max
   SEL_I2C = FALSE;
}


//-----------------------------------------------------------------------------
/*!
   \brief     Sel_Audio_CDC_fv

    this function controls the TDA7439 to switch to CDC 

   \author     Matthias Koelling
   \date       26.04.2009

   \param[in]  void
   \param[out] none
   \return     none
*/
//-----------------------------------------------------------------------------

void Sel_Audio_CDC_fv(void)
{
   SEL_I2C = TRUE;
   TDA7439_send_byte(VOLUME,VOL_MUTE);     // mute outputs
   TDA7439_send_byte(IN_SELECT,IN2);   // select input3 -> CDC
   TDA7439_send_byte(IN_GAIN,2);       // set gain to 2dB
   TDA7439_send_byte(VOLUME,MAIN_VOL);        // set volume to max
   SEL_I2C = FALSE;
}


//-----------------------------------------------------------------------------
/*!
   \brief     Sel_Audio_CDC_fv

    this function controls the TDA7439 to switch to AUX 

   \author     Matthias Koelling
   \date       26.04.2009

   \param[in]  void
   \param[out] none
   \return     none
*/
//-----------------------------------------------------------------------------

void Sel_Audio_AUX_fv(void)
{
   SEL_I2C = TRUE;
   TDA7439_send_byte(VOLUME,VOL_MUTE);     // mute outputs
   TDA7439_send_byte(IN_SELECT,IN4);   // select input4 -> AUX
   TDA7439_send_byte(IN_GAIN,0);       // set gain to 0dB
   TDA7439_send_byte(VOLUME,MAIN_VOL);        // set volume to max
   SEL_I2C = FALSE;
}

// eof
